@@ -12,8 +12,8 @@ use crate::{
     CompletionRelevance,
 };
 
-pub(crate) fn render_variant<'a>(
-    ctx: RenderContext<'a>,
+pub(crate) fn render_variant(
+    ctx: RenderContext<'_>,
     import_to_add: Option<ImportEdit>,
     local_name: Option<hir::Name>,
     variant: hir::Variant,
@@ -26,7 +26,6 @@ pub(crate) fn render_variant<'a>(
 #[derive(Debug)]
 struct EnumRender<'a> {
     ctx: RenderContext<'a>,
-    name: hir::Name,
     variant: hir::Variant,
     path: Option<hir::ModPath>,
     qualified_name: hir::ModPath,
@@ -58,7 +57,7 @@ impl<'a> EnumRender<'a> {
             ),
         };
 
-        EnumRender { ctx, name, variant, path, qualified_name, short_qualified_name, variant_kind }
+        EnumRender { ctx, variant, path, qualified_name, short_qualified_name, variant_kind }
     }
     fn render(self, import_to_add: Option<ImportEdit>) -> CompletionItem {
         let mut item = CompletionItem::new(
